#!/usr/bin/ksh
#**********************************************************************
#*-------------------------------------------------------------------------------
#* Licensed Materials - Property of IBM
#*
#* 5724-A18
#*
#* (c) Copyright IBM Corp. 2000, 2001, 2002
#*
#* US Government Users Restricted Rights - Use, duplication or
#* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#*-------------------------------------------------------------------------------
###########################################################################
# This is the script to wrap up the installation and invocation of
# WCSICChecker for SunOS. 
# 
# Author: Andrew Chen
# Created: Nov. 9 2001
# Last Modified: July 10 2002
############################################################################
############################################################################
# define defaults 
WCSINSTALLED=0
WCS51=0
WC54=0
ca=`/usr/bin/echo '\001'`

############################################################################
#  Tokenize the version, release, modification, and fixpak
#
Tokenize()
{
CURVER=$1

CURSOFT=$2

CUREDITION=$3

CURPATH=$4

XMLFILE1=$5

XMLFILE2=$6

CURVER1=`( /usr/bin/echo $CURVER | /usr/bin/awk '{FS="."}{print $1}')`
if [[ "$CURVER1" = "" ]]
then
   CURVER1="0"
fi

CURVER2=`( /usr/bin/echo $CURVER | /usr/bin/awk '{FS="."}{print $2}')`
if [[ "$CURVER2" = "" ]]
then
   CURVER2="0"
fi

CURVER3=`( /usr/bin/echo $CURVER | /usr/bin/awk '{FS="."}{print $3}')`

if [[ $CURSOFT = "WASJDK" ]];
then
TMPVER3=$CURVER3
CURVER3=`( /usr/bin/echo $TMPVER3 | /usr/bin/awk '{FS="_"}{print $1}')`
CURVER4=`( /usr/bin/echo $TMPVER3 | /usr/bin/awk '{FS="_"}{print $2}')`

else
CURVER4=`( /usr/bin/echo $CURVER | /usr/bin/awk '{FS="."}{print $4}')`
fi

if [[ "$CURVER3" = "" ]]
then
   CURVER3="0"
fi

if [[ "$CURVER4" = "" ]]
then
   CURVER4="0"
fi

if [[ $CURSOFT = "SunOS" || $CURSOFT = "DB2" ]];
then
sed s${ca}'<'$CURSOFT' edition="x" version="x" release="x" modification="x" fixpak="x" path="x">'${ca}\
'<'$CURSOFT' edition="'$CUREDITION'" version="'$CURVER1'" release="'$CURVER2'" modification="'$CURVER3\
'" fixpak="'$CURVER4'" path="'$CURPATH'">'${ca} $XMLFILE1 > $XMLFILE2
else
sed s${ca}'<'$CURSOFT' edition="x" version="x" release="x" modification="x" fixpak="x" path="x"/>'${ca}\
'<'$CURSOFT' edition="'$CUREDITION'" version="'$CURVER1'" release="'$CURVER2'" modification="'$CURVER3\
'" fixpak="'$CURVER4'" path="'$CURPATH'"/>'${ca} $XMLFILE1 > $XMLFILE2
fi

}
# check the installed package infomation and version levels
HardCheck()
{
FILESET=$1

TEMP=`(pkginfo | grep $FILESET)`

if [ $? -ne 0 ]
then
   return 3
else
   CURVERS=`(pkginfo -l $FILESET | grep "VERSION" | /usr/bin/awk '{print $2}')`   
   return 0 
fi
}

# Check OS system library
PatchCheck()
{
REQPATCH=$1

CURCOUNT=$2

XMLFILE1=$3

XMLFILE2=$4


REQMAJOR=`(echo $REQPATCH | /usr/bin/awk '{FS="-"}{print $1}')`
REQMINOR=`(echo $REQPATCH | /usr/bin/awk '{FS="-"}{print $2}')`
CURMINOR=00
HIMINOR=00
HIPATCH=

PATCHCOUNT=`(showrev -p | /usr/bin/grep -c $REQMAJOR)`

if [ PATCHCOUNT -gt 0 ];
then
   for PATCH in `(showrev -p | /usr/bin/grep $REQMAJOR | /usr/bin/awk '{print $2}')`;
   do
      CURMINOR=`(echo $PATCH | /usr/bin/awk '{FS="-"}{print $2}')`
      if [ $CURMINOR -ge $HIMINOR ];
      then
         HIMINOR=$CURMINOR
         HIPATCH=$PATCH
      fi
   done    

   if [ $HIMINOR -ge $REQMINOR ];
   then
      TEMP=`(echo $REQPATCH $HIPATCH | awk '{printf("%-20s  %-12s  PASS\n",$1,$2)}')`
      #echo "$TEMP"
      STATUS=1
   else
      TEMP=`(echo $REQPATCH $HIPATCH | awk '{printf("%-20s  %-12s  FAIL\n",$1,$2)}')`
      #echo "$TEMP"
      STATUS=-1
   fi
else
   TEMP=`(echo "$REQPATCH NONE" | awk '{printf("%-20s  %-12s  FAIL\n",$1,$2)}')`
   #echo "$TEMP"
   STATUS=-1
fi

# add to installStatus.xml
#sed s${ca}'<Patch name="'$REQPATCH'" msg="x" status="x"/>'\
#${ca}'<Patch name="'$REQPATCH'" msg="'"OS System Patch -- $TEMP"'" status="'$STATUS'"/>'\
sed s${ca}'<Patch number="'$CURCOUNT'" name="x" msg="x" status="x"/>'\
${ca}'<Patch name="'$REQPATCH'" msg="'"OS System Patch -- $TEMP"'" status="'$STATUS'"/>'\
${ca}1 $XMLFILE1 > $XMLFILE2
}

# check Solaris kernel configuration parameters for DB2
CheckSystemKernel()
{
PARAM=$1

REQVAL=$2
CURCOUNT=$3

XMLFILE1=$4
XMLFILE2=$5


TEMP=`(/usr/bin/grep "^set $PARAM" /etc/system)`

if [ $? -ne 0 ];
then
   TEMP="$PARAM  NOT FOUND     FAIL  $REQVAL"
   STATUS=-1
else
   CURVAL=`(grep "^set $PARAM" /etc/system | /usr/bin/cut -d"=" -f2)`
   # Remove the carriage return on end of value just in case
   CURVAL=`(echo $CURVAL | /usr/bin/awk '{FS="\r"}{print $1}')`
   if [[ $PARAM = "msgsys:msginfo_msgseg" && $MEMMB -ge 256 ]]; 
   then
         #echo $CURVAL $REQVAL
         if [ $CURVAL -eq $REQVAL ];
         then
            TEMP=`(echo "$PARAM $CURVAL" | awk '{printf("%-20s  %-12s  PASS\n",$1,$2)}')`            
	    STATUS=1
         else
            TEMP=`(echo "$PARAM $CURVAL" | awk '{printf("%-20s  %-12s  FAIL\n",$1,$2)}')`
            TEMP=`echo "$TEMP  max $REQVAL"`
	    STATUS=-1
         fi
    else   

		   if [ $CURVAL -ge $REQVAL ];
		   then
	    	      TEMP=`(echo "$PARAM $CURVAL" | awk '{printf("%-20s  %-12s  PASS\n",$1,$2)}')` 
		      STATUS=1         
		   else
		      TEMP=`(echo "$PARAM $CURVAL" | awk '{printf("%-20s  %-12s  FAIL\n",$1,$2)}')`
		      TEMP=`echo "$TEMP $REQVAL"`	 
		      STATUS=-1
   		   fi
	fi
fi	
# add to installStatus.xml
sed s${ca}'<KernelParam number="'$CURCOUNT'" name="x" msg="x" status="x"/>'\
${ca}'<KernelParam name="'$PARAM'" msg="'"Kernel Configuration Parameter -- $TEMP"'" status="'$STATUS'"/>'\
${ca} $XMLFILE1 > $XMLFILE2
#echo "----------------------- About to exit function CheckSystemKernel()"
}

############################################################################
# Check WebSphere Commerce version: 5.4 or 5.1?
# 
############################################################################
# check 5.1 first
HardCheck wcsbase
if [ $? -eq 0 ];
then
   EDITIONTAG="v51pro";
   WCINSTALLED=1;
   WCS51=1;
   WCEDITION="Professional"
   # set the default path for v5.1	
   WCSDIR=/opt/WebSphere/CommerceSuite
   WASDIR=/opt/IBMWebAS
   DB271HOME=/opt/IBMdb2/V7.1
   HTTPHOME=/opt/IBMHTTPD
   PAYMENTHOME=/opt/PaymentManager
   # check the existence of WebSphere Commerce Suite directory.
  if [[ ! -d ${WCSDIR} ]];
  then
   /usr/bin/echo ""
   /usr/bin/echo "ERROR: Websphere Commerce Suite NOT DETECTED. Expecting $WCSDIR"
   /usr/bin/echo ""
   exit 1
  fi
else
# check 5.4
HardCheck wcbase
if [ $? -eq 3 ];
then
   echo "ICChecker require WCS 5.1 or higher installed in your system...."
   echo "Exiting...."
   echo ""
   exit 1;
else
   # set the default path for v5.4
   WCSDIR=/opt/WebSphere/CommerceServer
   WASDIR=/opt/WebSphere/AppServer
   DB271HOME=/opt/IBMdb2/V7.1
   HTTPHOME=/opt/IBMHTTPD
   PAYMENTHOME=/opt/PaymentManager	   
fi

  WCINSTALLED=1;
  WC54=1;

# check the existence of WebSphere Commerce Suite directory.
if [[ ! -d ${WCSDIR} ]];
then
   /usr/bin/echo ""
   /usr/bin/echo "ERROR: Websphere Commerce NOT DETECTED. Expecting $WCSDIR"
   /usr/bin/echo ""
   exit 1
fi

# check WC 5.4 edition from build.txt
WCEDITION=`( /usr/bin/cat ${WCSDIR}/bin/build.txt | /usr/bin/awk '{FS=";"}{print $3}' | /usr/bin/awk '{print $2}')`

if [[ "${WCEDITION}" = "" ]];
then
   echo "---------------------------------------------------------"
   echo " EDITION: ERROR in build.txt file"
   echo "---------------------------------------------------------"
   exit 1;
elif [[ "${WCEDITION}" = "Professional" ]];
then
   EDITIONTAG="v54pro";

elif [[ "${WCEDITION}" = "Business" ]];
then
   EDITIONTAG="v54be";   
fi
echo ""
fi

WCSVERSION=$CURVERS

#echo "WCSINSTALLED=$WCSINSTALLED"
#echo "WCSVERSION=$WCSVERSION"
#echo "WCEDITION=$WCEDITION"
#echo "WCS51=$WCS51"
#echo "WC54=$WC54"



############################################################################
# create iccheker/bin and icchecker/log under WCS_InstallPath
#
############################################################################
[[ -d ${WCSDIR}/icchecker ]] || mkdir ${WCSDIR}/icchecker
[[ -d $WCSDIR/icchecker/bin ]] || mkdir $WCSDIR/icchecker/bin 
[[ -d $WCSDIR/icchecker/log ]] || mkdir $WCSDIR/icchecker/log
[[ -d $WCSDIR/icchecker/xml ]] || mkdir $WCSDIR/icchecker/xml
[[ -d $WCSDIR/icchecker/images ]] || mkdir $WCSDIR/icchecker/images
[[ -d $WCSDIR/icchecker/lib ]] || mkdir $WCSDIR/icchecker/lib
# d34130 - add a subdir called properties
[[ -d $WCSDIR/icchecker/properties ]] || mkdir $WCSDIR/icchecker/properties
[[ -d $WCSDIR/icchecker/help ]] || mkdir $WCSDIR/icchecker/help
ICCBIN=$WCSDIR/icchecker/bin
ICCLOG=$WCSDIR/icchecker/log
ICCXML=$WCSDIR/icchecker/xml
ICCHELP=$WCSDIR/icchecker/help
ICCIMAGES=$WCSDIR/icchecker/images
ICCLIB=$WCSDIR/icchecker/lib

############################################################################
# copy /bin from the source dir to iccheker/bin and
# change the mode of shell scipt files in icchecker/bin	
############################################################################
if [[ -d ./bin ]];
	then
		/usr/bin/cp ./bin/*.* ${ICCBIN}
	else
		/usr/bin/echo "ERROR: bin directory not found. Please reinstall."	
		exit 1
fi	
if [[ -d ./xml ]];
	then
		/usr/bin/cp ./xml/*.* ${ICCXML}
	else
		/usr/bin/echo "ERROR: xml directory not found. Please reinstall."	
		exit 1
fi
if [[ -d ./help ]];
	then
		/usr/bin/cp ./help/*.* ${ICCHELP}
	else
		/usr/bin/echo "ERROR: help directory not found. Please reinstall."	
		exit 1
fi
if [[ -d ./images ]];
	then
		/usr/bin/cp ./images/*.* ${ICCIMAGES}
	else
		/usr/bin/echo "ERROR: xml directory not found. Please reinstall."	
		exit 1
fi
if [[ -d ./lib ]];
	then
		/usr/bin/cp ./lib/*.* ${ICCLIB}
	else
		/usr/bin/echo "ERROR: lib directory not found. Please reinstall."	
		exit 1
fi
if [[ -f ${ICCBIN}/runAlias.sh ]];
      then
         /usr/bin/chmod a+x ${ICCBIN}/runAlias.sh         
      else
         /usr/bin/echo "ERROR: runAlias.sh not found. Expecting ${ICCBIN}/runAlias.sh"
         exit 1
fi

if [[ -f ${ICCBIN}/runPs.sh ]];
      then
         /usr/bin/chmod a+x ${ICCBIN}/runPs.sh         
      else
         /usr/bin/echo "ERROR: runPs.sh not found. Expecting ${ICCBIN}/runPs.sh"
         exit 1
fi


############################################################################
# make a backup of installStatus.xml and also a copy of it
#
 if [[ -f ${ICCXML}/InstallStatusTemplate.xml ]];
      then
         #/usr/bin/echo "Backing up InstallStatusTemplate.xml"
         /usr/bin/cp ${ICCXML}/InstallStatusTemplate.xml ${ICCXML}/InstallStatus.xml
         /usr/bin/cp ${ICCXML}/InstallStatusTemplate.xml ${ICCXML}/InstallStatus.xml.tmp
      else
         /usr/bin/echo "ERROR: InstallStatusTemplate.xml not found. Expecting ${ICCBIN}/InstallStatusTemplate.xml"
         exit 1
fi
ISXML=${ICCXML}/InstallStatus.xml
ISXMLTMP=${ICCXML}/InstallStatus.xml.tmp

/usr/bin/echo "Gathering system information, please wait...."


############################################################################
#  Add current date and time info
#
CURDATE=`/usr/bin/date '+DATE:%m-%d-%y'`
CURTIME=`/usr/bin/date '+TIME:%H:%M:%S'`
sed s${ca}'<Date>x</Date>'${ca}'<Date>'$CURDATE'</Date>'${ca} "$ISXML" > "$ISXMLTMP"
sed s${ca}'<Time>x</Time>'${ca}'<Time>'$CURTIME'</Time>'${ca} "$ISXMLTMP" > "$ISXML"

# change to <Version5.1> </Version5.1>
sed s${ca}'<VersionHW>'${ca}"<$EDITIONTAG>"${ca} "$ISXML" > "$ISXMLTMP"
sed s${ca}'</VersionHW>'${ca}"</$EDITIONTAG>"${ca} "$ISXMLTMP" > "$ISXML"
sed s${ca}'<VersionSW>'${ca}"<$EDITIONTAG>"${ca} "$ISXML" > "$ISXMLTMP"
sed s${ca}'</VersionSW>'${ca}"</$EDITIONTAG>"${ca} "$ISXMLTMP" > "$ISXML"



############################################################################
#  checking hardware and add to InstallStatus.xml
#
# check the machine type and architecture
MACHINETYPE=`uname -i`
ARCHITECTURE=`uname -p`
sed s:'<Machine type="x" architecture="x"/>':'<Machine type=\"'$MACHINETYPE'\" architecture=\"'$ARCHITECTURE'\"/>': "$ISXML" > "$ISXMLTMP"


# check the number of CPUs and get the Processor spd for each of them
# have to add more for Mutiple processor case
NCPU=`(uname -X | grep NumCPU | /usr/bin/awk '{print $3}' )`
sed s${ca}'<Cpu number="x">'${ca}'<Cpu number="'$NCPU'">'${ca} "$ISXMLTMP" > "$ISXML"


COUNT=0

for COUNT in `(psrinfo -v | grep "Status of" | /usr/bin/awk '{print $4}')`;
do
   CPUSPEED=`(psrinfo -v $COUNT | grep "MHz" | /usr/bin/awk '{print $6}')`
   sed s${ca}'<Processor slot="0" speed="x" unit="x"/>'${ca}'<Processor slot="0" speed="'$CPUSPEED'" unit="MHz"/>'${ca}  "$ISXML" > "$ISXMLTMP"
done


#
# Memory

MEMMB=`(prtconf | grep "Memory" | awk '{print $3}')`

MEMTOTAL=`expr $MEMMB \* 1024`

#echo "Total Physical Memory: $MEMTOTAL"
#echo "RAM(k) Check PER CPU:"
MEMPERCPU=`expr $MEMTOTAL / $NCPU`
sed s${ca}'<RAM size="x" unit="x"/>'${ca}'<RAM size="'$MEMPERCPU'" unit="KB"/>'${ca} "$ISXMLTMP" > "$ISXML"



# Paging Space
PAGETOTAL=0
NUMPAGES=`(swap -l | grep -c -v "THISISJUSTTOCOUNTLINES")`
NUMPAGES=`expr $NUMPAGES - 1`

if [ NUMPAGES -ge 1 ];
then
   COUNT=0
   for PAGESPACE in `(swap -l | /usr/bin/awk '{print $5}')`;
   do
      # Skip first line as it is the title
      if [ $COUNT -ge 1 ];
      then
         PAGETOTAL=`expr $PAGETOTAL + $PAGESPACE`
      fi
      COUNT=`expr $COUNT + 1`
   done

   # In 512K blocks ... convert to 1K blocks
   PAGETOTAL=`expr $PAGETOTAL / 2`
else
   PAGETOTAL=0
fi
   
sed s${ca}'<PAGINGSPACE size="x" unit="x"/>'${ca}'<PAGINGSPACE size="'$PAGETOTAL'" unit="KB"/>'${ca} "$ISXML" > "$ISXMLTMP"



# System PATH and Java Classpath
sed s${ca}'<EnvPATH value="x"/>'${ca}'<EnvPATH value="'$PATH'"/>'${ca} "$ISXMLTMP" > "$ISXML"
#if [ $CLASSPATH == ""]
#then 
# 	CLASSPATH="x"
#fi
# Java Level check

JAVALEVEL=`( /usr/bin/java -version 2>&1 | grep java | awk '{print $3}') | awk '{FS="\""}{print $2}'`
sed s${ca}'<Java Level="x" CLASSPATH="x"/>'${ca}'<Java Level="'$JAVALEVEL'" CLASSPATH="'$CLASSPATH'"/>'${ca} "$ISXML" > "$ISXMLTMP"	


###########################################################################
# Check installed software level
#
# OS Level for solaris
OSNAME=`uname`

OSLEVEL=`uname -r`
# fix for d35959
if [[ ${OSLEVEL} = "" ]];
then
	OSLEVEL="0.0.0.0"
fi

Tokenize $OSLEVEL $OSNAME "x" "x" "$ISXMLTMP" "$ISXML"

# OS System Library
# different in v54 and v51
# TO DO: change the messages
#if [[ $WCS51 = 1 && $OSLEVEL = "5.7" ]]
if [[ $WCS51 = 1 && $OSLEVEL = "5.7" ]]
then
	PatchCheck 106950-07 1 $ISXML $ISXMLTMP
	PatchCheck 106980-13 2 $ISXMLTMP $ISXML
	PatchCheck 107078-18 3 $ISXML $ISXMLTMP
	PatchCheck 107081-25 4 $ISXMLTMP $ISXML
	PatchCheck 107636-05 5 $ISXML $ISXMLTMP
	PatchCheck 107607-01 6 $ISXMLTMP $ISXML
elif [[ $WC54 = 1 && $OSLEVEL = "5.8" ]]	
then
	PatchCheck 108940-14 1 $ISXML $ISXMLTMP
	PatchCheck 108652-27 2 $ISXMLTMP $ISXML
	PatchCheck 108921-11 3 $ISXML $ISXMLTMP
	PatchCheck 108434-01 4 $ISXMLTMP $ISXML
	PatchCheck 109147-06 5 $ISXML $ISXMLTMP
	PatchCheck 108827-01 6 $ISXMLTMP $ISXML
fi	


	
# Websphere Commerce Suite
#
#  Add WCS version and installPath to the XML file
#
if [[ ${WCSVERSION} = "" ]];
then
	WCSVERSION="0.0.0.0"
	WCSDIR="x"
	WCEDITION="x"
fi

Tokenize $WCSVERSION "WCS" $WCEDITION $WCSDIR "$ISXML" "$ISXMLTMP"
# reset global variable CURVERS
CURVERS=""

# Websphere Application Server
#
# Add WAS version and installPath to the XML file
#

HardCheck WSserver
if [[ $CURVERS = "3.5" ]]
then
	WAS35=1;
	WASVERSION=3.5
	# check WAS3.5 home dir
        if [ ! -d ${WASDIR} ];
	then
	    echo "WebSphere Application Server Default directory $WASDIR NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the WAS HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      WASDIR=$CHECK_DIR
	      #/usr/bin/echo "WAS HOME is $WASDIR"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done
	fi
       # check 3.5 fixpak	
      for DIGIT in 0 1 2 3 4 5 6 7 8 9
      do
          TEMP=`(/usr/bin/grep "<version>3.5.$DIGIT</version>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
         if [[ $? = 0 ]]                  
	 then
	    WASVERSION=3.5.0.$DIGIT
	    break;
         fi
      done
      # was edition check
      TEMP=`(/usr/bin/grep "<value>advanced</value>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
      if [[ $? = 0 ]];                  
      then
      	WASEDITION="Advanced"
      else
      	WASEDITION="x"	
      fi	     
	
else
# check WAS 4.0 version
HardCheck WASserver

if [ $? -eq 3 ];
then
   echo "WAS not installed...."
   echo "Exiting...."
   echo ""
   exit 0;
elif [[ $CURVERS = "4.0.0" ]]
then
	WAS40=1
	WASVERSION=4.0
	# check WAS4.0 home dir
	if [ ! -d ${WASDIR} ];
	then
	    echo "WebSphere Application Server 4.0 Default directory $WASDIR NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the WAS HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      WASDIR=$CHECK_DIR
	      #/usr/bin/echo "WAS HOME is $WASDIR"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done
	fi
	
	# check 4.0 fixpak	
      for DIGIT in 0 1 2 3 4 5 6 7 8 9
      do
         TEMP=`(/usr/bin/grep "<version>4.0.$DIGIT</version>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
         if [[ $? = 0 ]];                  
	 then
	    WASVERSION=4.0.0.$DIGIT
	    break;
         fi
      done
      # was edition check
      TEMP=`(/usr/bin/grep "<value>AE</value>" ${WASDIR}/properties/com/ibm/websphere/product.xml)`
      if [[ $? = 0 ]];                  
      then
      	WASEDITION="Advanced"
      else
      	WASEDITION="x"	
      fi
    fi
fi      

#echo "WASVERSION=$WASVERSION"
#echo "WASDIR=$WASDIR"
#echo "WASEDITON=$WASEDITION"

# exception handling
if [[ "${WASVERSION}" = "" ]]; 
then
	WASVERSION="0.0.0.0"
	#WASDIR="x"	
	WASEDITION="x"
fi	
#need to reset CURVERS
CURVERS=""   


Tokenize $WASVERSION "WAS" $WASEDITION $WASDIR "$ISXMLTMP" "$ISXML"


#
# WAS_JDK level
#
if [ -f ${WASDIR}/java/jre/bin/java ];
then
   WASJAVALEVEL=`( ${WASDIR}/java/jre/bin/java -version 2>&1 | grep java | awk '{print $3}') | awk '{FS="\""}{print $2}'`
   WAS_JDKPATH=${WASDIR}/java/jre/bin/java       
fi
# exception handling
# fix for d35959
#if [[ "${WASJAVALEVEL}" = "" ]]; 
#then
# skip the check for WASJDK now
	WASJAVALEVEL="x.0.0.0"
	WAS_JDKPATH="x"
#fi
Tokenize $WASJAVALEVEL "WASJDK" "x" $WAS_JDKPATH "$ISXML" "$ISXMLTMP"

# Database - DB2
#
#echo "========================================================="
#echo "DATABASE: DB2  Check                           "
#echo "========================================================="
DBFOUND=0
O816=0
ORACLEFOUND=0
ORATAB=""

HardCheck db2rte71 
RETVAL=$?

if [ $RETVAL -eq 0 ];
then
   #echo "IBM DB2 7.1 DATABASE"
   #echo "Ports Used:"
   #grep "DB2 instance" /etc/services | /usr/bin/awk '{printf("%-20s  %-20s\n",$1,$2)}'
     
   DB2VERSION=$CURVERS	
   
   if [ ! -d ${DB271HOME} ];
   then
      echo "DB2 7.1 Default directory ${DB271HOME} NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the DB2 HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      DB271HOME=$CHECK_DIR
	     # /usr/bin/echo "DB2 Home is $DB271HOME"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done      
   fi

   #echo ""
   # echo "OS System Kernel Parameters /etc/system: Memory:$MEMMB"
   if [[ $MEMMB -ge 64 && $MEMMB -lt 128 ]];
      then
      if [[ ${WCS51} = 1 ]]
      then
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 130 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 128 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 256 6 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgseg 8192 7 $ISXMLTMP $ISXMLXML

      DIFF=`expr $MEMMB \* 1024 \* 1024 / 10`
      TEMP=`expr $MEMMB \* 1024 \* 1024`
      TEMP=`expr $TEMP - $DIFF`
      if [ $TEMP -lt 67108864 ];
      then
         TEMP=67108864
      fi
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 50 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 300 10 $ISXML $ISXMLTMP

      CheckSystemKernel semsys:seminfo_semmni 128 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmap 130 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 256 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmnu 256 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semume 50 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP
      elif [[ ${WC54} = 1 ]]
      then		
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 130 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 128 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 256 6 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgseg 8192 7 $ISXMLTMP $ISXMLXML

      TEMP=`expr $MEMMB \* 1024 \* 1024`
      TEMP=`expr $TEMP \* 2`
      if [ $TEMP -lt 134217728 ];
      then
         TEMP=134217728
      fi
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 16 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 256 10 $ISXML $ISXMLTMP

      CheckSystemKernel semsys:seminfo_semmni 300 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmsl 250 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 256 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semopm 200 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_seminfo 32767 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP
      fi	   
	  
   elif [[ $MEMMB -ge 128 && $MEMMB -lt 256 ]];
      then
      if [[ ${WCS51} = 1 ]]
      then
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 258 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 256 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 512 6 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgseg 16384 7 $ISXMLTMP $ISXML

      DIFF=`expr $MEMMB \* 1024 \* 1024 / 10`
      TEMP=`expr $MEMMB \* 1024 \* 1024`
      TEMP=`expr $TEMP - $DIFF`
      if [ $TEMP -lt 134217728 ];
      then
         TEMP=134217728
      fi 
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 50 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 300 10 $ISXML $ISXMLTMP

      CheckSystemKernel semsys:seminfo_semmni 256 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmap 258 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 512 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmnu 512 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semume 50 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP
      elif [[ ${WC54} = 1 ]]
      then		
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 258 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 256 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 512 6 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgseg 16384 7 $ISXMLTMP $ISXML

      TEMP=`expr $MEMMB \* 1024 \* 1024`
      TEMP=`expr $TEMP \* 2`
       if [ $TEMP -lt 268435456 ];
      then
         TEMP=268435456
      fi
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 16 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 256 10 $ISXML $ISXMLTMP

      CheckSystemKernel semsys:seminfo_semmni 300 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmsl 250 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 512 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semopm 200 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_seminfo 32767 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP
      fi		  
   elif [[ $MEMMB -ge 256 && $MEMMB -lt 512 ]];
      then
      if [[ ${WCS51} = 1 ]]
      then
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 258 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 256 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 1024 6 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgseg 32767 7 $ISXMLTMP $ISXML
      
      DIFF=`expr $MEMMB \* 1024 \* 1024 / 10`	  
      TEMP=`expr $MEMMB \* 1024 \* 1024`
	  TEMP=`expr $TEMP - $DIFF`
	  if [ $TEMP -lt 268435456 ];
      then
         TEMP=268435456
      fi
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 50 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 300 10 $ISXML $ISXMLTMP

      CheckSystemKernel semsys:seminfo_semmni 512 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmap 514 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 1024 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmnu 1024 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semume 50 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP

      elif [[ ${WC54} = 1 ]]
      then		
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 258 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 256 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 1024 6 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgseg 32767 7 $ISXMLTMP $ISXML
      
      TEMP=`expr $MEMMB \* 1024 \* 1024`
      TEMP=`expr $TEMP \* 2`
	if [ $TEMP -lt 536870912 ];
      then
         TEMP=536870912
      fi
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 16 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 256 10 $ISXML $ISXMLTMP

      CheckSystemKernel semsys:seminfo_semmni 300 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmsl 250 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 1024 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semopm 200 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_seminfo 32767 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP
      fi	  
	  
   elif [[ $MEMMB -ge 512 ]];
      then
      if [[ ${WCS51} = 1 ]]
      then
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 258 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 256 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 1024 6 $ISXML $ISXMLTMP
	  CheckSystemKernel msgsys:msginfo_msgseg 32767 7 $ISXMLTMP $ISXML
     
      DIFF=`expr $MEMMB \* 1024 \* 1024 / 10`
      TEMP=`expr $MEMMB \* 1024 \* 1024`
      TEMP=`expr $TEMP - $DIFF`
      if [ $TEMP -lt 536870912 ];
      then
         TEMP=536870912
      fi
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 50 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 300 10 $ISXML $ISXMLTMP
      
	  
      CheckSystemKernel semsys:seminfo_semmni 1024 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmap 1026 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 2048 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmnu 2048 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semume 50 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP
      
      elif [[ ${WC54} = 1 ]]
      then		
      CheckSystemKernel msgsys:msginfo_msgmax 65535 1 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmnb 65535 2 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgmap 258 3 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgmni 256 4 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgssz 16 5 $ISXMLTMP $ISXML
      CheckSystemKernel msgsys:msginfo_msgtql 1024 6 $ISXML $ISXMLTMP
      CheckSystemKernel msgsys:msginfo_msgseg 32767 7 $ISXMLTMP $ISXML
     
      TEMP=`expr $MEMMB \* 1024 \* 1024`
      TEMP=`expr $TEMP \* 2`
      if [ $TEMP -lt 4294967295 ];
      then
         TEMP=4294967295
      fi
      CheckSystemKernel shmsys:shminfo_shmmax $TEMP 8 $ISXML $ISXMLTMP
      CheckSystemKernel shmsys:shminfo_shmseg 16 9 $ISXMLTMP $ISXML
      CheckSystemKernel shmsys:shminfo_shmmni 256 10 $ISXML $ISXMLTMP
      
	  
      CheckSystemKernel semsys:seminfo_semmni 300 11 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semmsl 250 12 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_semmns 2048 13 $ISXMLTMP $ISXML
      CheckSystemKernel semsys:seminfo_semopm 200 14 $ISXML $ISXMLTMP
      CheckSystemKernel semsys:seminfo_seminfo 32767 15 $ISXMLTMP $ISXML
	  # make it even
	  cp $ISXML $ISXMLTMP
      fi
   else
      echo "FAIL: Invalid Memory Value for DB2 OS Kernel Settings: $MEMMB"
   fi
   DBFOUND=1
   DB2EDITION="Server" 
   
elif [ $RETVAL -eq 3 ];
then
   HardCheck db2cliv71
   RETVAL=$?
   if [ $RETVAL -eq 0 ];
   then
      #echo "IBM DB2 7.1 DATABASE Client"
      
      #echo "Ports Used:"
      #grep "DB2 instance" /etc/services | /usr/bin/awk '{printf("%-20s  %-20s\n",$1,$2)}'
 
    if [ ! -d ${DB271HOME} ];
	  then
	      echo "DB2 7.1 Default directory ${DB271HOME} NOT DETECTED"
	  while :
	   do
  	   read CHECK_DIR?"Please enter the DB2 HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      DB271HOME=$CHECK_DIR
	    #  /usr/bin/echo "DB2 Home is ${DB271HOME}"
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	   done
    fi 
    
   DB2EDITION="Client" 
   echo ""
   echo "** NOTE: Client Installation of DB2 detected. Remote DB assumed"
   echo ""
   DBFOUND=1     
   fi 
fi
# exception handling
if [[ "${DB2VERSION}" = "" ]]; 
then
	DB2VERSION="0.0.0.0"
	DB2EDITION="x"
	DB271HOME="x"
fi
Tokenize $DB2VERSION "DB2" $DB2EDITION $DB271HOME $ISXML $ISXMLTMP
#need to reset CURVERS
CURVERS=""


# Database - Oracle
# TO DO ------ if no Db detected, warn and exit

# Web Server - IBM HTTPD
# 

#echo "========================================================="
#echo "WebServer: IBM HTTP Server "
#echo "========================================================="
WEBSERVERFOUND=0

HardCheck IBMHTTPD
RETVAL=$?
if [ $RETVAL -eq 0 ];
then
   #echo "IBM HTTP SERVER"
   #echo ""
   WEBSERVERFOUND=1
   HTTPDVERSION=$CURVERS	
   if [ ! -d ${HTTPHOME} ];
   then
      echo "IBM HTTP Server default directory ${HTTPHOME} NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the IBM HTTP Server HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      HTTPHOME=$CHECK_DIR	      
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done      
	
   fi   
   # use version.signature as it has most accurate info
   if [ -f ${HTTPHOME}/version.signature ];
   then
      CURVERS=`( /usr/bin/cat ${HTTPHOME}/version.signature | awk '{print $4}')`
   fi   
      HTTPDVERSION=$CURVERS	
   else #HTTPD not installed
      HTTPVERSION=0.0.0.0     
fi
# exception handling
# fix for d35959
if [[ "${HTTPDVERSION}" = "" ]]; 
then
	HTTPDVERSION="0.0.0.0"
	HTTPHOME="x"
fi   

Tokenize $HTTPDVERSION "IBMHTTP" "x" $HTTPHOME $ISXMLTMP $ISXML
# reset global variable CURVERS
CURVERS=""

# Web Server - Sun iPlanet
#  TO DO --------------------- if no Web server found, warn and exit


# Payment Manager - instance name varies 
# TO DO
PAYMENTFOUND=0
PAYINFO=`(pkginfo | grep "IBM WebSphere Payment Manager - Framework")`
 
RETVAL=$?
if [ $RETVAL -eq 0 ];
then
   PAYINST=`(/usr/bin/echo $PAYINFO | /usr/bin/awk '{print $2}')`
   #echo "IBM WebSphere Payment Manager"
   #echo ""
   PAYMENTFOUND=1
   NUMINST=`(pkginfo -l $PAYINST | grep  -c "VERSION")`
   VERS=`(pkginfo -l $PAYINST | grep "VERSION" | /usr/bin/awk '{print $2}')`
   # get the last one in the list, NF - number of field in current record
   CURVERS=`(echo $VERS | /usr/bin/awk '{print $NF}')`    
   PAYMENTVERSION=$CURVERS
  
   if [ ! -d ${PAYMENTHOMEHOME} ];
   then
      echo "IBM WebSphere Payment Manager default directory ${PAYMENTHOME} NOT DETECTED"
	while :
	do
  	read CHECK_DIR?"Please enter the IBM WebSphere Payment Manager HOME directory:"

	   if [[ "${CHECK_DIR}" = "quit" ]];
	   then
		    read JUNK?"Press enter to continue."
		    exit 0
	   fi

	   if [[ -d ${CHECK_DIR} ]];
	   then
    	      PAYMENTHOME=$CHECK_DIR	      
	   else
    	  /usr/bin/echo "Invalid entry of $CHECK_DIR"
	      continue
	   fi

	   break;
	done      
   fi   
fi
# exception handling
if [[ "${PAYMENTVERSION}" = "" ]]; 
then
	PAYMENTVERSION="0.0.0.0"
	PAYMENTHOME="x"
fi	

Tokenize $PAYMENTVERSION "PaymentManager" "x" $PAYMENTHOME $ISXML $ISXMLTMP
# reset global variable CURVERS
CURVERS=""

# make sure the last one ends up with $ISXML
cp $ISXMLTMP $ISXML
rm $ISXMLTMP

#  need to include config classes in the classpath
#  setup Java runtime environment, need to run 1.2.2 or later!!!

export JAVA_HOME=${WASDIR}/java/jre
export JAVA_EXE=${JAVA_HOME}/bin/java
CLASSPATH=$CLASSPATH:$WCSDIR/lib/wcsconfig.jar
CLASSPATH=$CLASSPATH:$WCSDIR/lib/xml4j.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/xerces.jar
CLASSPATH=$CLASSPATH:${ICCLIB}/icchecker.jar
# d36920 - add XMLConfig.jar to the classpath
# add WC54 and WCS51 specific jar files
if [[ $WCS51 = 1 ]]
then
CLASSPATH=$CLASSPATH:$WASDIR/lib/ibmwebas.jar
else
CLASSPATH=$CLASSPATH:$WASDIR/lib/xmlconfig.jar
fi
# d36920 - add additional jar files to the classpath
CLASSPATH=$CLASSPATH:$WASDIR/lib/ujc.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/console.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/repository.jar
CLASSPATH=$CLASSPATH:$WASDIR/lib/tasks.jar

export CLASSPATH
#echo "CLASSPATH=$CLASSPATH"

############################################################################
#invoke icchecker through MainInputScreen
/usr/bin/echo "Running icchecker for Solaris, please wait...."
#echo "WCSDIR=${WCSDIR}"
#echo "EDITIONTAG=$EDITIONTAG"

${JAVA_EXE} com.ibm.commerce.icchecker.MainInputScreen ${WCSDIR} $EDITIONTAG 2>./log/error.log
